import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixPremiumDomainsV1ConnectedDomainSetupInfo from './premium-domains-v1-connected-domain-setup-info-connected-domain-setup-info.http.js';
export var ConnectionType;
(function (ConnectionType) {
    /** Used by sub domain */
    ConnectionType["UNKNOWN_CONNECTION_TYPE"] = "UNKNOWN_CONNECTION_TYPE";
    ConnectionType["POINTING"] = "POINTING";
    ConnectionType["NAMESERVERS"] = "NAMESERVERS";
    /**
     * internal used by photography company.
     * when a customer creates a photo album, each album has its sub domain and this sub domain
     * is not visible in my domains page.
     */
    ConnectionType["HIDDEN"] = "HIDDEN";
})(ConnectionType || (ConnectionType = {}));
/**
 * Retrieves information for the initial setup of a connected domain.
 *
 *
 * You must pass the relevant Wix account ID in the header of the call.
 *
 * > __Important:__ This call requires an account level API key and cannot be authenticated with the standard authorization header.
 * @param connectedDomainId - ID of the connected domain to retrieve setup information for.
 * Identical to the domain name including TLD.
 * @public
 * @requiredField connectedDomainId
 * @permissionId DOMAINS.READ_CONNECTED_DOMAINS
 * @returns Retrieved setup information.
 * @fqn com.wixpress.premium.domain.connected.ConnectedDomainSetupInfoService.GetConnectedDomainSetupInfo
 */
export async function getConnectedDomainSetupInfo(connectedDomainId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        connectedDomainId: connectedDomainId,
    });
    const reqOpts = ambassadorWixPremiumDomainsV1ConnectedDomainSetupInfo.getConnectedDomainSetupInfo(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data)
            ?.connectedDomainSetupInfo;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { connectedDomainId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['connectedDomainId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=premium-domains-v1-connected-domain-setup-info-connected-domain-setup-info.universal.js.map